Models
======

All data models are `Pydantic v2 <https://docs.pydantic.dev/latest/>`_
``BaseModel`` subclasses with full type annotations.

Enums
-----

.. automodule:: etoropy.models.enums
   :members:
   :show-inheritance:

Common
------

.. automodule:: etoropy.models.common
   :members:
   :show-inheritance:

Market Data
-----------

.. automodule:: etoropy.models.market_data
   :members:
   :show-inheritance:

Trading
-------

.. automodule:: etoropy.models.trading
   :members:
   :show-inheritance:

Feeds & Social
--------------

.. automodule:: etoropy.models.feeds
   :members:
   :show-inheritance:

WebSocket Messages
------------------

.. automodule:: etoropy.models.websocket
   :members:
   :show-inheritance:
